import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { Icon } from '../Icon/index.js';
import { getStyles } from './Breadcrumb.styles.js';
import { Link } from '../Link/index.js';

const getClassNames = classNamesFunction();
let BreadcrumbBase = class BreadcrumbBase extends BaseComponent {
  get classNames() {
    const {
      className,
      theme
    } = this;
    return getClassNames(getStyles, {
      theme,
      className
    });
  }

  onBreadcrumbClicked(event, item) {
    if (item.onClick) {
      item.onClick(event, item);
    }
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      items
    } = this;
    return h("div", {
      "class": classNames.root,
      "attrs": {
        "role": "navigation"
      }
    }, [h("ol", {
      "class": classNames.list
    }, [items.map((item, index) => h("li", {
      "key": index,
      "class": classNames.listItem
    }, [item.onClick || item.href ? h(Link, {
      "class": classNames.itemLink,
      "attrs": {
        "href": item.href
      },
      "on": {
        "click": ev => this.onBreadcrumbClicked(ev, item)
      }
    }, [item.text]) : h("span", {
      "class": classNames.item,
      "on": {
        "click": ev => this.onBreadcrumbClicked(ev, item)
      }
    }, [item.text]), index !== items.length - 1 && h(Icon, {
      "key": `icon-${index}`,
      "class": classNames.chevron,
      "attrs": {
        "icon-name": "ChevronRight"
      }
    })]))])]);
  }

};

__decorate([Prop({
  type: Array,
  required: true
}), __metadata("design:type", Array)], BreadcrumbBase.prototype, "items", void 0);

BreadcrumbBase = __decorate([Component], BreadcrumbBase);

export { BreadcrumbBase };
