import { __decorate, __metadata } from 'tslib';
import { Model, Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import { Icon } from '../Icon/index.js';
import { Label } from '../Label/index.js';

const getClassNames = classNamesFunction();
let CheckboxBase = class CheckboxBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.internalValue = this.checked || this.defaultChecked;
    this.isIndeterminate = this.indeterminate || this.defaultIndeterminate;
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      title,
      label
    } = this;
    return h("div", {
      "class": classNames.root
    }, [h("input", _mergeJSXProps([{
      "attrs": {
        "id": `Checkbox${this.uid}`
      },
      "class": classNames.input
    }, this.$attrs, {
      "attrs": {
        "disabled": this.disabled,
        "type": "checkbox"
      },
      "on": {
        "input": this.onInput
      }
    }])), h(Label, {
      "class": classNames.label,
      "attrs": {
        "for": `Checkbox${this.uid}`
      }
    }, [h("div", {
      "class": classNames.checkbox
    }, [h(Icon, {
      "attrs": {
        "icon-name": "CheckMark"
      },
      "class": classNames.checkmark
    })]), (label || this.$slots.default) && h("span", {
      "class": classNames.text,
      "attrs": {
        "title": title
      }
    }, [this.$slots.default || label])])]);
  }

  get classNames() {
    const {
      theme,
      className,
      disabled,
      isIndeterminate,
      internalValue,
      boxSide
    } = this;
    return getClassNames(this.styles, {
      theme,
      className,
      disabled,
      indeterminate: isIndeterminate,
      checked: internalValue,
      reversed: boxSide !== 'start',
      isUsingCustomLabelRender: true
    });
  }

  onValueChanged(value) {
    this.$emit('input', value);
  }

  onInput() {
    if (this.disabled) return;

    if (this.isIndeterminate) {
      this.internalValue = this.defaultChecked;
      this.isIndeterminate = false;
    } else {
      this.internalValue = !this.internalValue;
    }
  }

};

__decorate([Model('input', {
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "checked", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "defaultChecked", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "indeterminate", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "defaultIndeterminate", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CheckboxBase.prototype, "required", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], CheckboxBase.prototype, "label", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], CheckboxBase.prototype, "title", void 0);

__decorate([Prop({
  type: String,
  default: 'start',
  validator: v => ['start', 'end'].indexOf(v) > -1
}), __metadata("design:type", String)], CheckboxBase.prototype, "boxSide", void 0);

__decorate([Watch('internalValue'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean]), __metadata("design:returntype", void 0)], CheckboxBase.prototype, "onValueChanged", null);

CheckboxBase = __decorate([Component], CheckboxBase);

export { CheckboxBase };
