import VNodes from '../VNodes.js';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { Autofill } from '../Autofill/Autofill.js';
import { Callout } from '../Callout/Callout.js';
import { ActionButton } from '../Button/ActionButton/ActionButton.js';
import { IconButton } from '../Button/IconButton/IconButton.js';
import { ResizeObserver } from 'resize-observer';
import { getStyles } from './ComboBox.styles.js';
import { Label } from '../Label/index.js';
import { getClassNames } from './ComboBox.classNames.js';
import { Checkbox } from '../Checkbox/index.js';

var SearchDirection;

(function (SearchDirection) {
  SearchDirection[SearchDirection["backward"] = -1] = "backward";
  SearchDirection[SearchDirection["none"] = 0] = "none";
  SearchDirection[SearchDirection["forward"] = 1] = "forward";
})(SearchDirection || (SearchDirection = {}));

var HoverStatus;

(function (HoverStatus) {
  /** Used when the user was hovering and has since moused out of the menu items */
  HoverStatus[HoverStatus["clearAll"] = -2] = "clearAll";
  /** Default "normal" state, when no hover has happened or a hover is in progress */

  HoverStatus[HoverStatus["default"] = -1] = "default";
})(HoverStatus || (HoverStatus = {}));
/* ms */

let ComboBoxBase = class ComboBoxBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.state = {
      isOpen: false,
      selectedIndices: [],
      focused: false,
      suggestedDisplayValue: '',
      currentOptions: [],
      currentPendingValueValidIndex: 0,
      currentPendingValueValidIndexOnHover: 0,
      currentPendingValue: ''
    };
    this.comboBoxMenuWidth = 0;
  }

  mounted() {
    const cb = this._async.throttle(() => {
      if (!this.$refs.comboBoxWrapper) return;
      /** Update `comboBoxMenuWidth` with 60 fps. */

      this.comboBoxMenuWidth = this.$refs.comboBoxWrapper.clientWidth + 2;
    }, 1 / 60);

    const observer = new ResizeObserver(cb);
    observer.observe(this.$refs.comboBoxWrapper);
  }

  test() {
    const h = this.$createElement;
    return h("div", ["Test ", this.comboBoxMenuWidth]);
  }

  get hasErrorMessage() {
    const errorMessage = this.errorMessage;
    return !!(errorMessage && errorMessage.length > 0);
  }

  get classNames() {
    const {
      theme,
      className,
      styles: customStyles,
      disabled,
      required,
      allowFreeform,
      hasErrorMessage
    } = this;
    const {
      isOpen,
      focused,
      suggestedDisplayValue
    } = this.state;
    return getClassNames(getStyles(theme, customStyles), className, !!isOpen, !!disabled, !!required, !!focused, !!allowFreeform, !!hasErrorMessage);
  }
  /**
   * Gets the current comboBoxWrapper width, including its border offset. Has to be recalculated on each render cycle of
   * the Callout, in case the window size changed.
   */


  getComboBoxMenuWidth() {
    if (!this.$refs.comboBoxWrapper) return 0;
    return this.$refs.comboBoxWrapper.clientWidth + 2;
  }

  onFocus(e) {}

  onBlur(e) {
    console.log(e);
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      onFocus,
      onBlur,
      calloutProps,
      persistMenu,
      state,
      multiSelect
    } = this;
    return h("div", {
      "class": classNames.container
    }, [h(Label, {
      "attrs": {
        "for": `ComboBox${this.uid}`
      },
      "class": classNames.label
    }, ["Label"]), h("div", {
      "ref": "comboBoxWrapper",
      "class": classNames.root
    }, [h(Autofill, {
      "attrs": {
        "id": `ComboBox${this.uid}`,
        "type": "text",
        "role": "combobox"
      },
      "ref": "autofill",
      "class": classNames.input
    }), h(IconButton, {
      "class": "ms-ComboBox-CaretDown-button",
      "attrs": {
        "icon-props": {
          iconName: 'ChevronDown'
        }
      },
      "nativeOn": {
        "focus": onFocus,
        "blur": onBlur
      }
    })]), this.test(), (persistMenu || state.isOpen) && h("div", [h(Callout, {
      "class": css(classNames.callout, calloutProps ? calloutProps.className : undefined),
      "attrs": {
        "target": this.$refs.comboBoxWrapper,
        "is-beak-visible": false,
        "gap-space": 0,
        "do-not-layer": false,
        "callout-width": this.getComboBoxMenuWidth(),
        "callout-max-width": this.getComboBoxMenuWidth(),
        "hidden": persistMenu ? !state.isOpen : undefined
      }
    }, [h("div", {
      "ref": "comboBoxMenu",
      "class": classNames.optionsContainerWrapper
    }, [h("div", {
      "class": classNames.optionsContainer,
      "attrs": {
        "role": "listbox"
      }
    }, [multiSelect && h(Checkbox, {
      "class": "ms-ComboBox-option"
    }), h(ActionButton, {
      "class": "ms-ComboBox-option"
    })])])])])]);
  }

};

__decorate([Prop(), __metadata("design:type", Boolean)], ComboBoxBase.prototype, "allowFreeform", void 0);

__decorate([Prop(), __metadata("design:type", String)], ComboBoxBase.prototype, "autoComplete", void 0);

__decorate([Prop(), __metadata("design:type", String)], ComboBoxBase.prototype, "errorMessage", void 0);

__decorate([Prop(), __metadata("design:type", Object)], ComboBoxBase.prototype, "text", void 0);

__decorate([Prop(), __metadata("design:type", Object)], ComboBoxBase.prototype, "calloutProps", void 0);

__decorate([Prop(), __metadata("design:type", Object)], ComboBoxBase.prototype, "buttonIconProps", void 0);

__decorate([Prop(), __metadata("design:type", Object)], ComboBoxBase.prototype, "comboBoxOptionStyles", void 0);

__decorate([Prop(), __metadata("design:type", Boolean)], ComboBoxBase.prototype, "autofill", void 0);

__decorate([Prop(), __metadata("design:type", Boolean)], ComboBoxBase.prototype, "disabled", void 0);

__decorate([Prop(), __metadata("design:type", Boolean)], ComboBoxBase.prototype, "required", void 0);

__decorate([Prop(), __metadata("design:type", Boolean)], ComboBoxBase.prototype, "persistMenu", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], ComboBoxBase.prototype, "multiSelect", void 0);

ComboBoxBase = __decorate([Component({
  components: {
    Autofill,
    Label,
    IconButton,
    Callout,
    ActionButton,
    Checkbox,
    VNodes
  }
})], ComboBoxBase);

export { ComboBoxBase };
