import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent.js';
import { DEFAULT_CELL_STYLE_PROPS } from './DetailsRow.styles.js';

const getCellText = (item, column) => {
  let value = item && column && column.fieldName ? item[column.fieldName] : '';

  if (value === null || value === undefined) {
    value = '';
  }

  if (typeof value === 'boolean') {
    return value.toString();
  }

  return value;
};

let DetailsRowFields = class DetailsRowFields extends BaseComponent {
  constructor() {
    super(...arguments);
    this.showAnimation = true;
  }

  calcWidth(column) {
    const {
      cellStyleProps
    } = this;
    const width = typeof column.calculatedWidth === 'undefined' ? 'auto' : column.calculatedWidth + cellStyleProps.cellLeftPadding + cellStyleProps.cellRightPadding + (column.isPadded ? cellStyleProps.cellExtraRightPadding : 0) + 'px';
    return width;
  }

  render() {
    const h = arguments[0];
    const {
      rowClassNames,
      columns,
      showAnimation,
      item
    } = this;
    return h("div", {
      "class": rowClassNames.fields,
      "attrs": {
        "role": "presentation"
      }
    }, [columns.map((column, columnIndex) => {
      const slot = this.$scopedSlots[`cell.${column.key}`];
      return h("div", {
        "key": columnIndex,
        "attrs": {
          "role": column.isRowHeader ? 'rowheader' : 'gridcell',
          "aria-readonly": true
        },
        "style": {
          width: this.calcWidth(column)
        },
        "class": css(column.className, column.isMultiline && rowClassNames.isMultiline, column.isRowHeader && rowClassNames.isRowHeader, rowClassNames.cell, column.isPadded ? rowClassNames.cellPadded : rowClassNames.cellUnpadded, showAnimation && rowClassNames.cellAnimation)
      }, [slot ? slot({
        item,
        column
      }) : getCellText(item, column)]);
    })]);
  }

};

__decorate([Prop({
  type: Object,
  required: true
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "rowClassNames", void 0);

__decorate([Prop({
  type: Array,
  required: true
}), __metadata("design:type", Array)], DetailsRowFields.prototype, "columns", void 0);

__decorate([Prop({
  type: Object,
  required: true
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "item", void 0);

__decorate([Prop({
  type: Number,
  required: true
}), __metadata("design:type", Number)], DetailsRowFields.prototype, "itemIndex", void 0);

__decorate([Prop({
  type: Object,
  default: () => DEFAULT_CELL_STYLE_PROPS
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "cellStyleProps", void 0);

DetailsRowFields = __decorate([Component], DetailsRowFields);

export { DetailsRowFields };
