import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { PersonaSize } from '../Persona/Persona.types.js';
import { FacepileButton } from './FacepileButton/FacepileButton.js';
import { Persona } from '../Persona/index.js';

const getClassNames = classNamesFunction();
let FacepileBase = class FacepileBase extends BaseComponent {
  get singlePersona() {
    return this.personas.length === 1;
  }

  get classNames() {
    return getClassNames(this.styles, {
      theme: this.theme,
      className: this.className
    });
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      personas,
      singlePersona,
      personaSize
    } = this;
    return h("div", {
      "class": classNames.root
    }, [h("div", {
      "class": classNames.itemContainer
    }, [h("ul", {
      "class": classNames.members,
      "attrs": {
        "role": "listbox"
      }
    }, [personas.map((persona, index) => h("li", {
      "key": singlePersona ? 'persona' : `personaCoin-${index}`,
      "class": classNames.member,
      "attrs": {
        "role": "option"
      }
    }, [h("div", {
      "class": classNames.itemButton,
      "attrs": {
        "title": persona.personaName
      }
    }, [h(Persona, {
      "props": { ...persona
      },
      "attrs": {
        "image-initials": persona.imageInitials,
        "image-url": persona.imageUrl,
        "initials-color": persona.initialsColor,
        "allow-phone-initials": persona.allowPhoneInitials,
        "text": persona.personaName,
        "presence": 2,
        "size": personaSize,
        "styles": {
          details: {
            flex: '1 0 auto'
          }
        }
      }
    })])]))])])]);
  }

};

__decorate([Prop({
  type: Array,
  default: () => []
}), __metadata("design:type", Array)], FacepileBase.prototype, "personas", void 0);

__decorate([Prop({
  type: Number,
  default: PersonaSize.size32
}), __metadata("design:type", Number)], FacepileBase.prototype, "personaSize", void 0);

FacepileBase = __decorate([Component({
  components: {
    FacepileButton,
    Persona
  }
})], FacepileBase);

export { FacepileBase };
