import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import { PersonaSize, PersonaPresence } from './Persona.types.js';
import { PersonaCoin } from './PersonaCoin/index.js';

const getClassNames = classNamesFunction();
let PersonaBase = class PersonaBase extends BaseComponent {
  constructor() {
    super(...arguments);
    this.PersonaSize = PersonaSize;
  }

  get classNames() {
    const {
      theme,
      className,
      showSecondaryText,
      presence,
      size
    } = this;
    return getClassNames(this.styles, {
      theme: theme,
      className,
      showSecondaryText,
      presence,
      size
    });
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      coinSize,
      text,
      secondaryText,
      tertiaryText,
      optionalText,
      hidePersonaDetails,
      size
    } = this;
    return h("div", {
      "class": classNames.root,
      "style": coinSize ? {
        height: `${coinSize}px`,
        minWidth: `${coinSize}px`
      } : {}
    }, [h(PersonaCoin, {
      "props": { ...this.$props
      }
    }), (!hidePersonaDetails || size === PersonaSize.size8 || size === PersonaSize.size10 || size === PersonaSize.tiny) && h("div", {
      "class": classNames.details
    }, [h("div", {
      "attrs": {
        "dir": "auto"
      },
      "class": classNames.primaryText
    }, [h("div", [text])]), h("div", {
      "attrs": {
        "dir": "auto"
      },
      "class": classNames.secondaryText
    }, [h("div", [secondaryText])]), h("div", {
      "attrs": {
        "dir": "auto"
      },
      "class": classNames.tertiaryText
    }, [h("div", [tertiaryText])]), h("div", {
      "attrs": {
        "dir": "auto"
      },
      "class": classNames.optionalText
    }, [h("div", [optionalText])]), this.$slots.default])]);
  }

};

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "allowPhoneInitials", void 0);

__decorate([Prop({
  type: Number,
  default: PersonaPresence.none
}), __metadata("design:type", Number)], PersonaBase.prototype, "presence", void 0);

__decorate([Prop({
  type: Number,
  default: PersonaSize.size48
}), __metadata("design:type", Number)], PersonaBase.prototype, "size", void 0);

__decorate([Prop({
  type: Number,
  default: 0
}), __metadata("design:type", Number)], PersonaBase.prototype, "coinSize", void 0);

__decorate([Prop({
  type: [Number, String],
  default: undefined
}), __metadata("design:type", Number)], PersonaBase.prototype, "initialsColor", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "hidePersonaDetails", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PersonaBase.prototype, "text", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PersonaBase.prototype, "secondaryText", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PersonaBase.prototype, "tertiaryText", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PersonaBase.prototype, "optionalText", void 0);

__decorate([Prop({
  type: String,
  default: undefined
}), __metadata("design:type", String)], PersonaBase.prototype, "imageUrl", void 0);

__decorate([Prop({
  type: String,
  default: 'online'
}), __metadata("design:type", String)], PersonaBase.prototype, "status", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "isOutOfOffice", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "showSecondaryText", void 0);

PersonaBase = __decorate([Component], PersonaBase);

export { PersonaBase };
