import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { memoizeFunction, classNamesFunction } from '@uifabric-vue/utilities';
import { mergeStyleSets } from '@uifabric/styling';
import BaseComponent from '../../BaseComponent.js';
import { getStyles } from '../../Button/ActionButton/ActionButton.styles.js';
import { GridCell } from '../../../utilities/grid/GridCell.js';
import { getColorFromString } from '../../../utilities/color/getColorFromString.js';

const getColorPickerGridCellButtonClassNames = memoizeFunction((theme, className, variantClassName, iconClassName, menuIconClassName, disabled, checked, expanded, isSplit) => {
  const styles = getStyles(theme);
  return mergeStyleSets({
    root: ['ms-Button', styles.root, variantClassName, className, checked && ['is-checked', styles.rootChecked], disabled && ['is-disabled', styles.rootDisabled], !disabled && !checked && {
      selectors: {
        ':hover': styles.rootHovered,
        ':focus': styles.rootFocused,
        ':active': styles.rootPressed
      }
    }, disabled && checked && [styles.rootCheckedDisabled], !disabled && checked && {
      selectors: {
        ':hover': styles.rootCheckedHovered,
        ':active': styles.rootCheckedPressed
      }
    }],
    flexContainer: ['ms-Button-flexContainer', styles.flexContainer]
  });
});
const getClassNames = classNamesFunction();
let ColorPickerGridCellBase = class ColorPickerGridCellBase extends BaseComponent {
  get classNames() {
    const {
      styles,
      theme,
      circle,
      color,
      disabled,
      selected,
      height,
      width,
      borderWidth
    } = this;
    return getClassNames(styles, {
      theme,
      disabled,
      selected,
      circle,
      isWhite: this.isWhiteCell(color),
      height,
      width,
      borderWidth
    });
  }

  isWhiteCell(inputColor) {
    const color = getColorFromString(inputColor);
    return color.hex === 'ffffff';
  }

  render() {
    const h = arguments[0];
    const {
      classNames,
      color,
      circle
    } = this;
    return h(GridCell, {
      "class": classNames.colorCell
    }, [h("svg", {
      "class": classNames.svg,
      "attrs": {
        "viewBox": "0 0 20 20",
        "fill": getColorFromString(color).str
      }
    }, [circle ? h("circle", {
      "attrs": {
        "cx": "50%",
        "cy": "50%",
        "r": "50%"
      }
    }) : h("rect", {
      "attrs": {
        "width": "100%",
        "height": "100%"
      }
    })])]);
  }

};

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], ColorPickerGridCellBase.prototype, "circle", void 0);

__decorate([Prop({
  type: String
}), __metadata("design:type", String)], ColorPickerGridCellBase.prototype, "color", void 0);

__decorate([Prop({
  type: Boolean
}), __metadata("design:type", Boolean)], ColorPickerGridCellBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean
}), __metadata("design:type", Boolean)], ColorPickerGridCellBase.prototype, "selected", void 0);

__decorate([Prop({
  type: Number,
  default: 20
}), __metadata("design:type", Number)], ColorPickerGridCellBase.prototype, "height", void 0);

__decorate([Prop({
  type: Number,
  default: 20
}), __metadata("design:type", Number)], ColorPickerGridCellBase.prototype, "width", void 0);

__decorate([Prop({
  type: Number,
  default: 2
}), __metadata("design:type", Number)], ColorPickerGridCellBase.prototype, "borderWidth", void 0);

ColorPickerGridCellBase = __decorate([Component({
  components: {
    GridCell
  }
})], ColorPickerGridCellBase);

export { ColorPickerGridCellBase };
