import { createTheme, loadTheme as loadTheme$1 } from '@uifabric/styling';
import { toKebabCase } from '../utilities/toKebabCase.js';
import * as index from '../components/index.js';
import { registerCSSVars } from './registerCSSVars.js';

function loadTheme(theme, useCSSVars = false) {
  const _theme = createTheme(theme);

  if (useCSSVars) {
    let {
      palette,
      semanticColors
    } = _theme; // generate new css vars

    palette = registerCSSVars('palette', palette);
    semanticColors = registerCSSVars('semanticColors', semanticColors); // update theme

    loadTheme$1({
      palette,
      semanticColors
    });
  }

  return _theme;
}
function install(Vue, options = {}, theme = {}) {
  for (const componentName in index) {
    const Component = index[componentName];

    if (Component && Component.prototype instanceof Vue) {
      const name = `${options.prefix || 'f'}-${toKebabCase(componentName)}`;
      Vue.component(name, Component);
    }
  }

  loadTheme(theme, options.useCSSVars);
}
/*

============================
    CSS Vars
--neutralLight: #eaeaea;
--bodyFrameBackground: var(--neutralLight)

{
  neutralLight: 'var(--neutralLight)'
}
{
  bodyFrameBackground: 'var(--neutralLight)'
}

======================================
    No CSS Vars
{
  neutralLight: '#eaeaea'
}
{
  bodyFrameBackground: '#eaeaea'
}

 */

export default install;
export { loadTheme };
