import { getColorFromRGBA } from './getColorFromRGBA.js';
import { cssColor } from './cssColor.js';

/**
 * Converts a CSS color string to a color object.
 * Note that hex colors *must* be prefixed with # to be considered valid.
 *
 * `inputColor` will be used unmodified as the `str` property of the returned object.
 * Alpha defaults to 100 if not specified in `inputColor`.
 * Returns undefined if the color string is invalid/not recognized.
 */

function getColorFromString(inputColor) {
  const color = cssColor(inputColor);

  if (!color) {
    return;
  }

  return { ...getColorFromRGBA(color),
    str: inputColor
  };
}

export { getColorFromString };
